Name:      igor
Version:   0.4.1
Release:   5%{?dist}
Summary:   Automated distribution life-cycle testing (daemon)

License:   LGPLv2
Url:       http://www.github.com/fabiand/igor
# curl -L -o %%{name}-%%{version}.tar.gz https://github.com/fabiand/%%{name}/archive/%%{version}.tar.gz
Source:    https://github.com/fabiand/%{name}/archive/%{version}.tar.gz#/%{name}-%{version}.tar.gz
Group:     Development/Libraries
BuildArch: noarch

BuildRequires: python2-devel

Requires: %{name}-common = %{version}-%{release}
Requires:  /usr/bin/sudo
Requires:  livecd-tools
Requires:  genisoimage
Requires:  redis, python-redis
Requires:  python-yaml
Requires:  python-bottle


%description
Igor is a small daemon to continuous automated testing of PXE based Linux
distributions with cobbler, libvirt and real hardware.
It is intended to be combined with Jenkins and to test oVirt Node.

Install %{name}-systemd on a host to run igor as a system service.
Install %{name}-client on a host to control an igor daemon.
Install %{name}-slave-systemd on a host to let it run the testcases.


%package common
Summary:   Files shared between Igor daemon and client
Requires:  python-lxml


%description common
A number of files shared between the Igor daemon and client.


%package systemd
Summary:   Files to run igor under systemd
Requires:  %{name} = %{version}-%{release}
BuildRequires:    systemd-units
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd


%description systemd
This package contains all .service files to run igor as a deamon under systemd.
Install this package to run igor as a daemon system wide.


%package client
Summary:   Client to communicate with an Igor daemon
Requires:  %{name}-common = %{version}-%{release}
Requires:  firewalld
Requires:  python-fabulous
Requires:  libnotify
Requires:  python-redis


%description client
The client is used to initiate jobs, create profiles etc. and query all sorts
of informations.
Basically it is an CLI to Igor's RESTish API.


%package slave
Summary:   Slave which executes the steps on the target host


%description slave
The slave is executing the testsuites on the target host.
It is started as a service.


%package slave-systemd
Summary:   systemd service to start the slave on the target host
Requires:  %{name}-slave = %{version}-%{release}
Requires:  systemd
Requires(post):   systemd
Requires(preun):  systemd
Requires(postun): systemd


%description slave-systemd
This package contains the systemd service files to start the slave on boot.
It is required to boot the slave on boot to communicate with the daemon.


%prep
%setup -q


%build
%{__python} setup.py build


%install
%{__python} setup.py install --root=%{buildroot}

# Make some scripts executable to silence rpmlint
chmod a+x %{buildroot}/%{python_sitelib}/%{name}/daemon/data/*.sh
chmod a+x %{buildroot}/%{_bindir}/igor-slave

# Use the example as the real config file
mv %{buildroot}/%{_sysconfdir}/igord/igord.cfg.example %{buildroot}/%{_sysconfdir}/igord/igord.cfg


%post systemd
%systemd_post igord.service
%systemd_post igord-event-publisher.service


%preun systemd
%systemd_preun igord.service
%systemd_preun igord-event-publisher.service


%post slave-systemd
if [ $1 -eq 1 ] ; then
    # Initial installation
    /bin/systemctl daemon-reload >/dev/null 2>&1 || :
    /bin/systemctl enable igor-slave.service >/dev/null 2>&1 || :
fi


%files
%doc README COPYING
# FIXME add license file (landing with next upstream release)
%config(noreplace) %{_sysconfdir}/igord/igord.cfg
%{_sysconfdir}/igord/hook.d/*
%{python_sitelib}/%{name}/daemon
%{python_sitelib}/%{name}*.egg-info
%{_bindir}/igord


%files common
%{python_sitelib}/%{name}/__init__.py*
%{python_sitelib}/%{name}/log.py*
%{python_sitelib}/%{name}/common.py*
%{python_sitelib}/%{name}/reports.py*
%{python_sitelib}/%{name}/utils.py*
%{python_sitelib}/%{name}/data


%files client
%{python_sitelib}/%{name}/client
%{_bindir}/igorc


%files systemd
%{_unitdir}/igord.service


%files slave
%{_bindir}/igor-slave


%files slave-systemd
%{_unitdir}/igor-slave.service


%changelog
* Wed Jun 17 2015 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-5
- Rebuilt for https://fedoraproject.org/wiki/Fedora_23_Mass_Rebuild

* Sat Jun 07 2014 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.1-4
- Rebuilt for https://fedoraproject.org/wiki/Fedora_21_Mass_Rebuild

* Wed Oct 09 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.4.1-3
- Introduce systemd subpackages for service files (prepare EL6 usage)
- Update Source0 URL

* Fri Aug 09 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.4.1-2
- Fix cfg location

* Fri Aug 09 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.4.1-1
- Update to 0.4.1
- More requirements
- Default config file

* Sat Aug 03 2013 Fedora Release Engineering <rel-eng@lists.fedoraproject.org> - 0.4.0-2
- Rebuilt for https://fedoraproject.org/wiki/Fedora_20_Mass_Rebuild

* Thu Jul 18 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.4.0-1
- Update to latest upstream
- Upstream is now at github
- Introduce common and client subpackages
- Add redis dependency

* Wed Apr 03 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.3.0-4
- Drop define, as it was used only in one place

* Wed Apr 03 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.3.0-3
- Remove clean
- Specify python version
- Remove CFLAGS in build

* Wed Apr 03 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.3.0-2
- Add systemd macros

* Wed Apr 03 2013 Fabian Deutsch <fabiand@fedoraproject.org> - 0.3.0-1
- Initial package
